==> mythplugins-0.18.1.tar.bz2: mythplugins-0.18.1/mythdvd/i18n/mythdvd_nl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>De verbinding met MTD is verbroken. Dit is niet goed.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Kan geen verbinding maken met MTD. Probeer MTD te starten door op een nr. toets te drukken. Als dit bericht blijft staan is er iets ernstig fout.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Kan geen verbinding maken met MTD.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Netwerk error (socket-communicatie).</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Onbekende fout.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Taak %1 van %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Geen taken. Druk 0 om een DVD te &quot;rippen&quot;.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Geen taken. Bezig met controleren en/of wachten op DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Geen taken. Druk 0 om een CD te &quot;rippen&quot;.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Bezig met annuleren...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nieuwe rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Annuleer taak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>
        
U heeft geen VCD-afspeelcommando gedefinieerd.
</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>OK, ik ga naar het Instellingen-scherm</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Er is geen VCD-apparaat ingesteld.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

U heeft geen DVD-afspeelcommando gedefinieerd.
</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Er is geen DVD-apparaat ingesteld.
</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Path naar VCD-apparaat</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Dit apparaat moet bestaan en de gebruiker moet leesbevoegdheid hebben.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Path naar DVD-apparaat</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Algemene Instellingen</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>DVD-afspeelcommando</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Dit kan elke DVD-speler zijn (bv. MPlayer, ogle, xine, enz.). %d wordt vervangen door het hierboven ingestelde DVD-apparaat (bv. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>VCD-afspeelcommando</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Dit kan elke VCD-speler zijn (bv. MPlayer, xine, enz). %d wordt vervangen door het hierboven ingestelde VCD-apparaat (bv. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>DVD-afspeelinstellingen</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>VCD-afspeelinstellingen</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Map voor tijdelijke bestanden.</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Deze map moet bestaan en de gebruiker moet schrijfbevoegdheid tot deze map hebben.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Afspeelcommando</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Dit commando wordt gebruikt om de geselecteerde titel vooraf af te spelen. Indien aanwezig wordt %t vervangen door titel, %d door apparaat, %a door audiospoor en %c door audiokanaal.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Ondertitel argument:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Wanneer er ondertitels gekozen werden, wordt dit commando toegevoegd aan het afspeelcommando om ondertitels vooraf te bekijken. Indien aanwezig wordt %s vervangen door ondertiteltrack.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Basis transcode-commando</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Dit is het basiscommando (zonder argumenten) om transcode te starten.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTD-poortnummer</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Het poortnummer dat gebruikt wordt voor communicatie met MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>MTD logt naar het terminalvenster</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Indien geselecteerd, zal MTD naar het terminalvenster waaruit het gestart werd loggen. Anders wordt er een bestand aangemaakt (mtd.log) in de rip-map.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Transcode AC3-audio</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Indien geselecteerd, zal MTD AC3-audio (Dolby Digital) standaard in de uiteindelijke bestanden bewaren.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Gebruik liever xvid dan divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Indien geselecteerd, zal MTD de (open, vrije) xvid-codec gebruiken i.pv. divx waar mogelijk.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Nice level voor MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Bepaalt de prioriteit voor MTD. Een hoger cijfer betekent lagere prioriteit (meer CPU naar andere taken).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Geripte video-segmenten</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Wanneer ingesteld op iets anders dan 0, zullen geripte video-bestanden opgedeeld worden in bestanden van dit formaat (in MB). Zowel voor &quot;perfecte kwaliteit&quot; als &quot;gemiddelde kwaliteit&quot;.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVD-ripper instellingen</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD instellingen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Wacht op DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Bezig met importeren ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfecte DVD Rip van %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Transcode van %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Wacht op toestemming om te beginnen met transcode</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Transcode Pass 1 van 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Transcode Pass 2 van 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Bezig met transcode ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transcode denkt na </translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Gelijktijdige Transcode-taken</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Bepaalt het aantal gelijktijdige transcode taken. Indien 1 (standaard), zal er slechts een actieve taak zijn.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Bij invoer DVD</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Doe niets</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>Speel DVD</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>Importeer DVD</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Media-monitoring moet geactiveerd zijn om dit toe te laten (Instellingen -&gt; Algemeen -&gt; CD/DVD Monitor)</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>Toon MythDVD menu</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Importeer/Transcode</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Taak 1 van 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Kies:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kwaliteit:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Geluidsspoor:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3-geluid:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Ondertitels:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Bekijken:</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titel 1 van 1</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titel %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfect</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titel %1 van %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Verwerk de geselecteerde titel</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Verwerk de geselecteerde titels</translation>
    </message>
</context>
</TS>

==> mythplugins-0.19.tar.bz2: mythplugins-0.19/mythdvd/i18n/mythdvd_nl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>De verbinding met MTD is verbroken. Dit is niet goed.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Kan geen verbinding maken met MTD. Probeer MTD te starten door op een nummertoets te drukken. Als dit bericht blijft staan is er iets ernstig fout.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Kan geen verbinding maken met MTD. Host werd niet gevonden.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Netwerkfout (socket-communicatie).</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Onbekende fout.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Taak %1 van %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Geen taken. Op 0 om drukken een DVD te &quot;rippen&quot;.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Geen taken. Bezig met controleren en/of wachten op DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Geen taken. Op 0 drukken om een CD te &quot;rippen&quot;.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Bezig met annuleren...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nieuwe rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Taak annuleren</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>
        
U heeft geen VCD-afspeelcommando gedefinieerd.
</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>OK, ik ga naar het Instellingen-scherm</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Er is geen VCD-apparaat ingesteld.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Er is geen DVD-apparaat ingesteld.
</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Path naar VCD-apparaat</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Dit apparaat moet bestaan en de gebruiker moet leesbevoegdheid hebben.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Path naar DVD-apparaat</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Algemene instellingen</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>DVD-afspeelcommando</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Dit kan elke DVD-speler zijn (bv. MPlayer, ogle, xine, enz.). %d wordt vervangen door het hierboven ingestelde DVD-apparaat (bv. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>VCD-afspeelcommando</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Dit kan elke VCD-speler zijn (bv. MPlayer, xine, enz). %d wordt vervangen door het hierboven ingestelde VCD-apparaat (bv. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>DVD-afspeelinstellingen</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>VCD-afspeelinstellingen</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Map voor tijdelijke bestanden.</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Deze map moet bestaan en de gebruiker moet schrijfbevoegdheid tot deze map hebben.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Afspeelcommando</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Dit commando wordt gebruikt om de geselecteerde titel vooraf af te spelen. Indien aanwezig wordt %t vervangen door titel, %d door apparaat, %a door audiospoor en %c door audiokanaal.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Ondertitel argument:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Wanneer er ondertitels gekozen werden, wordt dit commando toegevoegd aan het afspeelcommando om ondertitels vooraf te bekijken. Indien aanwezig wordt %s vervangen door ondertiteltrack.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Basis transcode-commando</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Dit is het basiscommando (zonder argumenten) om transcode te starten.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTD-poortnummer</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Het poortnummer dat gebruikt wordt voor communicatie met MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>MTD logt naar het terminalvenster</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Indien geselecteerd, zal MTD naar het terminalvenster waaruit het gestart werd loggen. Anders wordt er een bestand aangemaakt (mtd.log) in de rip-map.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Transcode AC3-audio</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Indien geselecteerd, zal MTD AC3-audio (Dolby Digital) standaard in de uiteindelijke bestanden bewaren.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Xvid boven divx verkiezen</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>MTD zal de (open, vrije) xvid-codec gebruiken i.p.v. divx, waar mogelijk.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Nice level voor MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Bepaalt de prioriteit voor MTD. Een hoger cijfer betekent lagere prioriteit (meer CPU naar andere taken).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Geripte video-segmenten</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Wanneer ingesteld op iets anders dan 0, zullen geripte video-bestanden opgedeeld worden in bestanden van dit formaat (in MB). Zowel voor &quot;perfecte kwaliteit&quot; als &quot;gemiddelde kwaliteit&quot;.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVD-ripper instellingen</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD instellingen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Wacht op toegang tot DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Bezig met importeren ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfecte DVD-rip van %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Transcode van %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Wacht op toestemming om te beginnen met transcode</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Transcode Pass 1 van 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Transcode Pass 2 van 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Bezig met transcode ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transcode denkt na </translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Gelijktijdige transcode-taken</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Bepaalt het aantal gelijktijdige transcode taken. Indien 1 (standaard), zal er slechts één actieve taak zijn.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Bij invoer DVD</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Niets doen</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>DVD afspelen</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>DVD importeren</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Media-monitoring moet geactiveerd zijn (Instellingen -&gt; Algemeen -&gt; CD/DVD Monitor)</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>MythDVD menu tonen</translation>
    </message>
    <message>
        <source>ISO copy of %1</source>
        <translation>ISO kopie van %1</translation>
    </message>
    <message>
        <source>Waiting for access to DVD</source>
        <translation>Aan het wachten op toegang tot de DVD</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Importeer/Transcode</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Taak 1 van 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Kies:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kwaliteit:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Geluidsspoor:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3-geluid:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Ondertitels:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Bekijken:</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titel 1 van 1</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titel %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfect</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titel %1 van %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Geselecteerde titel verwerken</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Geselecteerde titels verwerken</translation>
    </message>
    <message>
        <source>ISO Image</source>
        <translation>ISO-kopie</translation>
    </message>
</context>
</TS>
